==> n3_sdk-1.3.1r03.zip: n3_sdk-1.3.1/lib/component/n3c_media-1.0.1-min.js <==

N3C.MediaPlayer=Class.cast({Extends:N3C,Const:{HAVE_NOTHING:0,HAVE_MEDIADATA:1,HAVE_CURRENT_DATA:2,HAVE_FUTURE_DATA:3,HAVE_ENOUGH_DATA:4,MEV_LOADSTART:"loadstart",MEV_PROGRESS:"progress",MEV_SUSPEND:"suspend",MEV_LOAD:"load",MEV_ABORT:"abort",MEV_ERROR:"error",MEV_EMPTIED:"emptied",MEV_PLAY:"play",MEV_PAUSE:"pause",MEV_LOADEDMETADATA:"loadedmetadata",MEV_LOADEDDATA:"loadeddata",MEV_WAITING:"waiting",MEV_PLAYING:"playing",MEV_CANPLAY:"canplay",MEV_CANPLAYTHROUGH:"canplaythrough",MEV_SEEKING:"seeking",MEV_SEEKED:"seeked",MEV_TIMEUPDATE:"timeupdate",MEV_ENDED:"ended",MEV_RATECHANGE:"ratechange",MEV_DURATIONCHANGE:"durationchange",MEV_VOLUMECHANGE:"volumechange",MEV_STALLED:"stalled"},Static:{EHS:null,MTB_MP4:"mp4",MTB_OGG:"ogg",MTB_WEBM:"webm",MTB_MP3:"mpeg",VIDEO_MIME_PLAYABLES:null,AUDIO_MIME_PLAYABLES:null,getVideoMimeType:function(s){var ext=(N3C.REX_EXT.exec(s))[1];if(ext){return this.VIDEO_FILE_TO_TYPES[ext];}
return null;},getAudioMimeType:function(s){var ext=(N3C.REX_EXT.exec(s))[1];if(ext){return this.AUDIO_FILE_TO_TYPES[ext];}
return null;},isPlayableType:function(t){return this.MIME_PLAYABLES[t];}},Loader:function(){var cls=this;var vp="video",ap="audio",sep="/",tl;var playables={"":0,"maybe":1,"probably":2,};var pl=cls.MIME_PLAYABLES={};var v=document.createElement(vp);tl=cls.VIDEO_FILE_TO_TYPES={"mp4":vp+sep+cls.MTB_MP4,"ogv":vp+sep+cls.MTB_OGG,"webm":vp+sep+cls.MTB_WEBM};for(var e in tl){var mt=tl[e];pl[mt]=v.canPlayType?(playables[v.canPlayType(mt)]):0;}
var a=document.createElement(ap);tl=cls.AUDIO_FILE_TO_TYPES={"m4a":ap+sep+cls.MTB_MP4,"ogg":ap+sep+cls.MTB_OGG,"wav":ap+sep+cls.MTB_WEBM,"webm":ap+sep+cls.MTB_WEBM,"mp3":ap+sep+cls.MTB_MP3};for(var e in tl){var mt=tl[e];pl[mt]=a.canPlayType?(playables[a.canPlayType(mt)]):0;}},_w:0,_h:0,_p:null,_preload:null,_controls:null,_autoplay:null,_crossorigin:null,_canplay:false,_si:null,_subs:null,_listeners:null,newInstance:function(id,dc,w,h,preload,controls,autoplay,crossorigin){this.superClass(document.createElement("div"));this.setID(id);if(dc){this.attachDesign(dc);}
this._w=w;this._h=h;this.setSize(this._w,this._h);this._preload=preload;this._controls=controls||false;this._autoplay=autoplay||false;this._crossorigin=crossorigin;this._listeners=[];},Virtual:{presetSource:function(src,type,codecs){this._canplay=false;if(!type){type=this.getMimeType(src);}
var r=N3C.MediaPlayer.isPlayableType(type);if(r>0){var si=this._si;if(!si||si[4]<r){this._si=[src,type,codecs,r];}}
return r;},presetSubtitle:function(src,vals,label,kind,lang,def){var subs=this._subs;if(!subs){this._subs=subs=[];}
subs.push([src,vals,label,kind,lang,!!def]);},getMimeType:function(src){return null;},requestFullscreen:function(){},exitFullscreen:function(){},open:function(){var p=this.openMedia().raw;if(p.canPlayType!=null){var _this=this;p.addEventListener("canplay",function(){if(!_this._canplay){_this._p.play();}
_this._canplay=true;},true);var ls=this._listeners;for(var i=0,ev;ev=ls[i];i++){p.addEventListener(ev[0],(function(po,ev){return function(){var e=ev[0],m=ev[1],o=ev[2];m.call(null,po,e,o);};})(this,ev),true);}
p.load();this._p=p;}
return this;},close:function(b){this.pause();if(b){this._detachSources();}
else{this.removeChildren();this._p=null;}
this._canplay=false;},play:function(d){d=d||0;if(!this.mediaOpened()){this.open();}
if(this._canplay){this._p.play();}},pause:function(){var p=this._p;if(p){p.pause();}},stop:function(){var p=this._p;if(p){p.pause();p.currentTime=p.initialTime||0;}},mute:function(){if(this._p){this._p.muted=!(this._p.muted);}},initialTime:function(){if(this._p){return this._p.initialTime||0;}
return-1;},currentTime:function(){if(this._p){return this._p.currentTime;}
return-1;},seek:function(t){if(this._p){this._p.currentTime=t;}},getVolume:function(){if(this._p){return this._p.volume;}
return 0;},setVolume:function(v){if(this._p){this._p.volume=v;}},setControls:function(b){if(this._p){this._p.controls=b;}},duration:function(){if(this._p){return this._p.duration;}
return 0;},isPaused:function(){var p=this._p;if(p){return(p.paused||p.ended);}
return true;},isMuted:function(){var p=this._p;if(p){return p.muted;}
return true;},mediaOpened:function(){return this._p&&this._p.childNodes&&this._p.childNodes.length>0;},addSource:function(src,type,codecs){if(!type){type=N3C.MediaPlayer.getMimeType(src);}
var r=N3C.MediaPlayer.isPlayableType(type);if(r>0){var si=this._si;if(!si||si[3]<r){this._si=[src,type,codecs,r];var p=this._p;p.removeChild(p.firstChild);p.appendChild(this._createSrc(src,type,codecs));}}
return r;},resetSources:function(){var p=this._p;p.removeChild(p.firstChild);var si=this._si;p.appendChild(this._createSrc(si[0],si[1],si[2]));},openMedia:function(){return null;},_detachSources:function(){if(this._p){while(this._p.firstChild){this._p.removeChild(this._p.firstChild);}}}},getReadyState:function(){return this._p.readyState||null;},addEventListener:function(e,m,o){this._listeners.push([e,m,o]);},removeSources:function(){this._detachSources();this._si=null;return this;},_createSrc:function(src,type,codecs){var s=document.createElement("source");s.setAttribute("src",src);if(type){s.setAttribute("type",type);}
if(codecs){s.setAttribute("codecs",codecs);}
return s;},_addSubtitles:function(p){var subs=this._subs;if(subs){for(var i=0,sbi;sbi=subs[i];i++){var src=sbi[0];var vals=sbi[1];var label=sbi[2];var kind=sbi[3];var srclang=sbi[4];var showing=sbi[5];if(vals){if(!p.addTextTrack){continue;}
var track=p.addTextTrack(kind,label,srclang);if(showing===true){track.mode="showing";}
var cueClass=window.VTTCue||window.TextTrackCue;for(var j=0,val;val=vals[j];j++){var cue=new cueClass(val.range[0],val.range[1],val.text);if(val.position!==void(0)){cue.position=val.position;}
if(val.line!==void(0)){cue.line=val.line;}
if(val.align!==void(0)){cue.align=val.align;}
track.addCue(cue);}}
else{var t=document.createElement("track");t.src=src;t.label=label;t.kind=kind;t.srclang=srclang;t.default=showing;p.appendChild(t);}}}}});N3C.Video=Class.cast({Extends:N3C.MediaPlayer,Static:{_fsv:null,exitFullscreen:function(){if(this._fsv){this._fsv.exitFullscreen();this._fsv=null;}}},_poster:null,newInstance:function(id,dc,w,h,poster,preload,controls,autoplay,crossorigin){this.superClass(id,dc,w,h,preload,controls,autoplay,crossorigin);this._poster=poster;},getMimeType:function(src){return N3C.MediaPlayer.getVideoMimeType(src);},requestFullscreen:function(){var v=this._p||{};if(v.requestFullscreen){v.requestFullscreen();}
else if(v.webkitRequestFullscreen){v.webkitRequestFullscreen();}
else if(v.mozRequestFullScreen){v.mozRequestFullScreen();}
else if(v.msRequestFullscreen){v.msRequestFullscreen();}
else if(v.webkitEnterFullscreen){v.webkitEnterFullscreen();}
else{return;}
N3C.Video._fsv=this;},exitFullscreen:function(){var v=this._p||{};if(v.exitFullscreen){v.exitFullscreen();}
else if(v.webkitExitFullscreen){v.webkitExitFullscreen();}
else if(v.mozCancelFullScreen){v.mozCancelFullScreen();}
else if(v.msExitFullscreen){v.msExitFullscreen();}
else if(v.webkitCancelFullscreen){v.webkitCancelFullscreen();}
else{return;}
N3C.Video._fsv=null;},openMedia:function(){var v=this._p;if(!v){v=document.createElement("video");v.id=this.getID()+"_v";v.style.cssText="width:100%;height:100%";if(this._poster){v.poster=this._poster;}
if(this._preload){v.preload=this._preload;}
if(this._crossorigin){v.setAttribute("crossorigin",this._crossorigin);}
v.controls=this._controls;v.autoplay=this._autoplay;this.raw.appendChild(v);}
var si=this._si;v.appendChild(this._createSrc(si[0],si[1],si[2]));this._addSubtitles(v);return new N3C(v);}});N3C.Audio=Class.cast({Extends:N3C.MediaPlayer,newInstance:function(id,dc,w,h,preload,controls,autoplay,crossorigin){this.superClass(id,dc,w,h,preload,controls,autoplay,crossorigin);},getMimeType:function(src){return N3C.MediaPlayer.getAudioMimeType(src);},openMedia:function(){var a=this._p;if(!a){a=document.createElement("audio");a.id=this.getID()+"_a";if(this._preload){a.preload=this._preload;}
if(this._crossorigin){v.setAttribute("crossorigin",this._crossorigin);}
a.controls=this._controls;a.autoplay=this._autoplay;this.raw.appendChild(a);}
var si=this._si;a.appendChild(this._createSrc(si[0],si[1],si[2]));this._addSubtitles(a);return new N3C(a);}});N3C.NetVideo=Class.cast({Extends:N3C.MediaPlayer,Implements:N3C.Sandbox.ContentsLoadedListener,_sb:null,newInstance:function(id,dc,w,h,sb,autoplay){this.superClass(id,dc,w,h,false,false,autoplay);this._sb=sb;},presetSource:function(src,type,codecs){this._si=src;return true;},openMedia:function(){if(!this._si){return null;}
if(this._sb){var sb=new N3C.Sandbox(this.getID()+"_i",this._w,this._h);sb.loadScript(this,this._si,this);}
else{N3C.Secure.inquire(this);this.setVal(this._si);}
return this;},sandboxContentsLoaded:function(sandbox,params){var sbb=sandbox.getBody();for(var i=0,sz=sbb.childCount();i<sz;i++){var node=sbb.childAt(i);}}});

==> n3_sdk-1.3.3r03.zip: n3_sdk-1.3.3/lib/component/n3c_media-1.0.1-min.js <==

N3C.MediaPlayer=Class.cast({Extends:N3C,Const:{HAVE_NOTHING:0,HAVE_MEDIADATA:1,HAVE_CURRENT_DATA:2,HAVE_FUTURE_DATA:3,HAVE_ENOUGH_DATA:4,MEV_LOADSTART:"loadstart",MEV_PROGRESS:"progress",MEV_SUSPEND:"suspend",MEV_LOAD:"load",MEV_ABORT:"abort",MEV_ERROR:"error",MEV_EMPTIED:"emptied",MEV_PLAY:"play",MEV_PAUSE:"pause",MEV_LOADEDMETADATA:"loadedmetadata",MEV_LOADEDDATA:"loadeddata",MEV_WAITING:"waiting",MEV_PLAYING:"playing",MEV_CANPLAY:"canplay",MEV_CANPLAYTHROUGH:"canplaythrough",MEV_SEEKING:"seeking",MEV_SEEKED:"seeked",MEV_TIMEUPDATE:"timeupdate",MEV_ENDED:"ended",MEV_RATECHANGE:"ratechange",MEV_DURATIONCHANGE:"durationchange",MEV_VOLUMECHANGE:"volumechange",MEV_STALLED:"stalled"},Static:{EHS:null,MTB_MP4:"mp4",MTB_OGG:"ogg",MTB_WEBM:"webm",MTB_MP3:"mpeg",VIDEO_MIME_PLAYABLES:null,AUDIO_MIME_PLAYABLES:null,getVideoMimeType:function(s){var ext=(N3C.REX_EXT.exec(s))[1];if(ext){return this.VIDEO_FILE_TO_TYPES[ext];}
return null;},getAudioMimeType:function(s){var ext=(N3C.REX_EXT.exec(s))[1];if(ext){return this.AUDIO_FILE_TO_TYPES[ext];}
return null;},isPlayableType:function(t){return this.MIME_PLAYABLES[t];}},Loader:function(){var cls=this;var vp="video",ap="audio",sep="/",tl;var playables={"":0,"maybe":1,"probably":2,};var pl=cls.MIME_PLAYABLES={};var v=document.createElement(vp);tl=cls.VIDEO_FILE_TO_TYPES={"mp4":vp+sep+cls.MTB_MP4,"ogv":vp+sep+cls.MTB_OGG,"webm":vp+sep+cls.MTB_WEBM};for(var e in tl){var mt=tl[e];pl[mt]=v.canPlayType?(playables[v.canPlayType(mt)]):0;}
var a=document.createElement(ap);tl=cls.AUDIO_FILE_TO_TYPES={"m4a":ap+sep+cls.MTB_MP4,"ogg":ap+sep+cls.MTB_OGG,"wav":ap+sep+cls.MTB_WEBM,"webm":ap+sep+cls.MTB_WEBM,"mp3":ap+sep+cls.MTB_MP3};for(var e in tl){var mt=tl[e];pl[mt]=a.canPlayType?(playables[a.canPlayType(mt)]):0;}},_w:0,_h:0,_p:null,_preload:null,_controls:null,_autoplay:null,_crossorigin:null,_canplay:false,_si:null,_subs:null,_listeners:null,newInstance:function(id,dc,w,h,preload,controls,autoplay,crossorigin){this.superClass(document.createElement("div"));this.setID(id);if(dc){this.attachDesign(dc);}
this.setSize(w,h);this._w=w;this._h=h;this._preload=preload;this._controls=controls||false;this._autoplay=autoplay||false;this._crossorigin=crossorigin;this._listeners=[];},Virtual:{presetSource:function(src,type,codecs){this._canplay=false;if(!type){type=this.getMimeType(src);}
var r=N3C.MediaPlayer.isPlayableType(type);if(r>0){var si=this._si;if(!si||si[4]<r){this._si=[src,type,codecs,r];}}
return r;},presetSubtitle:function(src,vals,label,kind,lang,def){var subs=this._subs;if(!subs){this._subs=subs=[];}
subs.push([src,vals,label,kind,lang,!!def]);},getMimeType:function(src){return null;},requestFullscreen:function(){},exitFullscreen:function(){},open:function(){var p=this.openMedia().raw;if(p.canPlayType!=null){var _this=this;p.addEventListener("canplay",function(){if(!_this._canplay){_this._p.play();}
_this._canplay=true;},true);var ls=this._listeners;for(var i=0,ev;ev=ls[i];i++){p.addEventListener(ev[0],(function(po,ev){return function(){var e=ev[0],m=ev[1],o=ev[2];m.call(null,po,e,o);};})(this,ev),true);}
p.load();this._p=p;}
return this;},close:function(b){this.pause();if(b){this._detachSources();}
else{this.removeChildren();this._p=null;}
this._canplay=false;},play:function(d){d=d||0;if(!this.mediaOpened()){this.open();}
if(this._canplay){this._p.play();}},pause:function(){var p=this._p;if(p){p.pause();}},stop:function(){var p=this._p;if(p){p.pause();p.currentTime=p.initialTime||0;}},mute:function(){if(this._p){this._p.muted=!(this._p.muted);}},initialTime:function(){if(this._p){return this._p.initialTime||0;}
return-1;},currentTime:function(){if(this._p){return this._p.currentTime;}
return-1;},seek:function(t){if(this._p){this._p.currentTime=t;}},getVolume:function(){if(this._p){return this._p.volume;}
return 0;},setVolume:function(v){if(this._p){this._p.volume=v;}},setControls:function(b){if(this._p){this._p.controls=b;}},duration:function(){if(this._p){return this._p.duration;}
return 0;},isPaused:function(){var p=this._p;if(p){return(p.paused||p.ended);}
return true;},isMuted:function(){var p=this._p;if(p){return p.muted;}
return true;},mediaOpened:function(){return this._p&&this._p.childNodes&&this._p.childNodes.length>0;},addSource:function(src,type,codecs){var cls=N3C.MediaPlayer;if(!type){type=cls.getMimeType(src);}
var r=cls.isPlayableType(type);if(r>0){var si=this._si;if(!si||si[3]<r){this._si=[src,type,codecs,r];var p=this._p;p.removeChild(p.firstChild);p.appendChild(this._createSrc(src,type,codecs));}}
return r;},resetSources:function(){var p=this._p;p.removeChild(p.firstChild);var si=this._si;p.appendChild(this._createSrc(si[0],si[1],si[2]));},openMedia:function(){return null;},_detachSources:function(){if(this._p){while(this._p.firstChild){this._p.removeChild(this._p.firstChild);}}}},getReadyState:function(){return this._p.readyState||null;},addEventListener:function(e,m,o){this._listeners.push([e,m,o]);},removeSources:function(){this._detachSources();this._si=null;return this;},_createSrc:function(src,type,codecs){var s=document.createElement("source");s.setAttribute("src",src);if(type){s.setAttribute("type",type);}
if(codecs){s.setAttribute("codecs",codecs);}
return s;},_addSubtitles:function(p){var subs=this._subs;if(subs){for(var i=0,sbi;sbi=subs[i];i++){var src=sbi[0];var vals=sbi[1];var label=sbi[2];var kind=sbi[3];var srclang=sbi[4];var showing=sbi[5];if(vals){if(!p.addTextTrack){continue;}
var track=p.addTextTrack(kind,label,srclang);if(showing===true){track.mode="showing";}
var cueClass=window.VTTCue||window.TextTrackCue;for(var j=0,val;val=vals[j];j++){var cue=new cueClass(val.range[0],val.range[1],val.text);if(val.position!==void(0)){cue.position=val.position;}
if(val.line!==void(0)){cue.line=val.line;}
if(val.align!==void(0)){cue.align=val.align;}
track.addCue(cue);}}
else{var t=document.createElement("track");t.src=src;t.label=label;t.kind=kind;t.srclang=srclang;t.default=showing;p.appendChild(t);}}}}});N3C.Video=Class.cast({Extends:N3C.MediaPlayer,Static:{_fsv:null,exitFullscreen:function(){if(this._fsv){this._fsv.exitFullscreen();this._fsv=null;}}},_poster:null,newInstance:function(id,dc,w,h,poster,preload,controls,autoplay,crossorigin){this.superClass(id,dc,w,h,preload,controls,autoplay,crossorigin);this._poster=poster;},getMimeType:function(src){return N3C.MediaPlayer.getVideoMimeType(src);},requestFullscreen:function(){var v=this._p||{};if(v.requestFullscreen){v.requestFullscreen();}
else if(v.webkitRequestFullscreen){v.webkitRequestFullscreen();}
else if(v.mozRequestFullScreen){v.mozRequestFullScreen();}
else if(v.msRequestFullscreen){v.msRequestFullscreen();}
else if(v.webkitEnterFullscreen){v.webkitEnterFullscreen();}
else{return;}
N3C.Video._fsv=this;},exitFullscreen:function(){var v=this._p||{};if(v.exitFullscreen){v.exitFullscreen();}
else if(v.webkitExitFullscreen){v.webkitExitFullscreen();}
else if(v.mozCancelFullScreen){v.mozCancelFullScreen();}
else if(v.msExitFullscreen){v.msExitFullscreen();}
else if(v.webkitCancelFullscreen){v.webkitCancelFullscreen();}
else{return;}
N3C.Video._fsv=null;},openMedia:function(){var v=this._p;if(!v){v=document.createElement("video");v.id=this.getID()+"_v";v.style.cssText="width:100%;height:100%";if(this._poster){v.poster=this._poster;}
if(this._preload){v.preload=this._preload;}
if(this._crossorigin){v.setAttribute("crossorigin",this._crossorigin);}
v.controls=this._controls;v.autoplay=this._autoplay;this.raw.appendChild(v);}
var si=this._si;v.appendChild(this._createSrc(si[0],si[1],si[2]));this._addSubtitles(v);return new N3C(v);}});N3C.Audio=Class.cast({Extends:N3C.MediaPlayer,newInstance:function(id,dc,w,h,preload,controls,autoplay,crossorigin){this.superClass(id,dc,w,h,preload,controls,autoplay,crossorigin);},getMimeType:function(src){return N3C.MediaPlayer.getAudioMimeType(src);},openMedia:function(){var a=this._p;if(!a){a=document.createElement("audio");a.id=this.getID()+"_a";if(this._preload){a.preload=this._preload;}
if(this._crossorigin){v.setAttribute("crossorigin",this._crossorigin);}
a.controls=this._controls;a.autoplay=this._autoplay;this.raw.appendChild(a);}
var si=this._si;a.appendChild(this._createSrc(si[0],si[1],si[2]));this._addSubtitles(a);return new N3C(a);}});N3C.NetVideo=Class.cast({Extends:N3C.MediaPlayer,Implements:N3C.Sandbox.ContentsLoadedListener,_sb:null,newInstance:function(id,dc,w,h,sb,autoplay){this.superClass(id,dc,w,h,false,false,autoplay);this._sb=sb;},presetSource:function(src,type,codecs){this._si=src;return true;},openMedia:function(){if(!this._si){return null;}
var n3c=N3C;if(this._sb){var sb=new n3c.Sandbox(this.getID()+"_i",this._w,this._h);sb.loadScript(this,this._si,this);}
else{n3c.Secure.inquire(this);this.setVal(this._si);}
return this;},sandboxContentsLoaded:function(sandbox,params){var sbb=sandbox.getBody();for(var i=0,sz=sbb.childCount();i<sz;i++){var node=sbb.childAt(i);}}});
